View source: R/utils-helpers.R
| ci_clopper_pearson | R Documentation |
Computes an exact binomial confidence interval for a proportion.
ci_clopper_pearson(x, n, conf_level = 0.95)
x |
Number of successes |
n |
Total number of trials |
conf_level |
Confidence level |
Used by the quantile-binned summary layer (see er_plot_add_quantiles())
to compute empirical response-rate confidence intervals. This assumes a
binary (0/1) response.
Named numeric vector, with confidence level stored as an attribute
ci_clopper_pearson(1, 10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.