View source: R/er-style-registry.R
| er_style_labels | R Documentation |
style dispatchStyle builder functions can be tagged with a "label" attribute used to
register a convenient short name for that style: er_style_labels() lists
the currently registered styles, optionally filtered to a single layer.
er_style_labels(layer = NULL)
layer |
A single layer name (e.g. |
A tibble with one row per registered (layer, label) pair and
columns layer, label, and style (the builder function itself).
er_style_labels("tte_summary")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.