er_tte_build: Build and render a time-to-event plot

View source: R/er-tte-api.R

er_tte_buildR Documentation

Build and render a time-to-event plot

Description

Assembles the layers for a time-to-event plot object: a survival panel that displays the curve, censor, summary, and model layers' geoms, when present. When a risk table layer is also present the result contains two panels stacked vertically.

Usage

er_tte_build(object)

Arguments

object

Partially constructed plot (has S3 class er_tte).

Details

The user does not typically invoke this function directly. Instead, it is called automatically when plot() is called.

Value

The input object, with object$output (the composed plot – a single ggplot2 object, or a patchwork object when the risktable layer is present) populated.

See Also

er_tte(), er_tte_add_curve(), er_tte_add_censor(), er_tte_add_risktable(), er_tte_add_summary()


erplots documentation built on Oct. 4, 2026, 5:06 p.m.