| er_tte_add_censor | R Documentation |
Adds the censoring layer to a TTE plot, showing the times at which a subject was censored, read from the fit already stored internally within the plot object.
er_tte_add_censor(object, style = NULL, ...)
object |
Partially constructed plot (has S3 class |
style |
Style used to draw the censoring marks layer. Can
either be a string corresponding to one of the registered style labels
(e.g., |
... |
Additional named arguments forwarded to the |
The input object, with the censor layer added.
The following pre-defined styles are available for this layer. Please see the documentation for the corresponding builder function to see what customisation options are available:
| Label | Builder | Description |
"ticks" | er_style_tte_censor_ticks() | Tick marks at each censoring time, on the curve's current step height (the only built-in, and the default). |
See er_style_tte() for details on how style builder functions are
defined for the TTE mini-grammar, should a custom style be required.
er_tte(), er_style_tte_censor_ticks()
library(survival)
lung |>
er_tte(time, status == 2) |>
er_tte_add_curve() |>
er_tte_add_censor() |>
plot()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.