| er_tte_build | R Documentation |
Assembles the layers for a time-to-event plot object: a survival panel that displays the curve, censor, summary, and model layers' geoms, when present. When a risk table layer is also present the result contains two panels stacked vertically.
er_tte_build(object)
object |
Partially constructed plot (has S3 class |
The user does not typically invoke this function directly. Instead, it
is called automatically when plot() is called.
The input object, with object$output (the composed plot
– a single ggplot2 object, or a patchwork object when the
risktable layer is present) populated.
er_tte(), er_tte_add_curve(), er_tte_add_censor(),
er_tte_add_risktable(), er_tte_add_summary()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.